@@ -6,7 +6,7 @@ import mlflow
 from waveletai._version import get_versions
 from waveletai import constants, envs
 from waveletai.backends.hosted_backend import HostedBackend
-from waveletai.constants import ModelRegisterMode, Visibility, DataSource, FileExt
+from waveletai.constants import ModelRegisterMode, Visibility, DataSource, FileExt, ModelSourceType
 from waveletai.exceptions import InitFailed
 from waveletai.sessions import Session
 from waveletai.utils import MLflowModuleRegister, set_mlflow_tracing_waveletai_store
@@ -201,7 +201,7 @@ def upload_dataset_artifacts(dataset_id, path):
     return _get_backend().upload_dataset_artifacts(dataset_id, path)
 
 
-def create_model(name, desc=None, git_url=None, http_url=None, visibility=Visibility.PRIVATE.value):
+def create_model(name, desc=None, git_url=None, http_url=None, visibility=Visibility.PRIVATE.value, source=ModelSourceType.GITCODE.value):
     """
     创建模型
     :param visibility: 公有私有 public private 默认 private
@@ -210,9 +210,10 @@ def create_model(name, desc=None, git_url=None, http_url=None, visibility=Visibi
     :param auth_id: auth_id 默认空
     :param name:模型名称
     :param desc:模型备注 默认空
+    :param source:模型来源 flow:画布 gitcode:git代码
     :return:
     """
-    return _get_backend().create_model(name, desc, git_url, http_url, visibility)
+    return _get_backend().create_model(name, desc, git_url, http_url, visibility, source)
 
 
 def get_model():
@@ -223,15 +224,16 @@ def get_model():
     return _get_backend().get_model()
 
 
-def register_model_version(desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
+def register_model_version(desc, artifacts, mode=ModelRegisterMode.PYFUNC.value, json_data=None):
     """
     注册模型库版本
     :param desc: 备注
     :param artifacts: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
     :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
+    :param json_data: 模型版本其他信息
     :return:
     """
-    return _get_backend().register_model_version(desc, artifacts, mode)
+    return _get_backend().register_model_version(desc, artifacts, mode, json_data)
 
 
 def get_model_version_by_model(version):
@@ -300,12 +302,12 @@ def delete_model():
     return _get_backend().delete_model()
 
 
-def list_model_versions():
+def list_model_versions(page=1, pagesize=10):
     """
     获取注册的各版本模型信息列表
     :return:
     """
-    return _get_backend().list_model_versions()
+    return _get_backend().list_model_versions(page, pagesize)
 
 
 def abandon_model_version(version):
@@ -480,17 +482,6 @@ def set_tags(tags):
     return mlflow.set_tags(tags)
 
 
-def download_feature_zip(feature_id, destination, unzip=False):
-    """
-    通过特征id下载特征zip包到本地指定目录
-    :param feature_id:特征id
-    :param destination:本地存储地址 默认空
-    :param unzip: 是否解压 默认不解压
-    :return:
-    """
-    return _get_backend().download_feature_zip(feature_id, destination, unzip)
-
-
 def upload_artifact(local_file, artifact_path, run_id):
     """
     上传模型文件
