@@ -36,6 +36,7 @@ from waveletai.utils.datastream import FileStream, FileChunkStream, FileChunk
 import zipfile
 from waveletai.experiment import Experiment, MLFlowExperiment, MLFlowRun, MLflowLatestMetric, MLFlowParam, MLFlowTag
 import pandas as pd
+import time
 
 _logger = logging.getLogger(__name__)
 
@@ -966,17 +967,21 @@ class HostedBackend(Backend):
     @with_api_exceptions_handler
     @require_app
     def _get_feature_zip_path(self, feature_id, feature_type):
+        client_ip = self._get_ip()
         if feature_type is None:
             feature_type = FeatureType.FILE.value
-        res = self._session.get(
-            url=f'{self.api_address}/{self.app_id}/data/feature/{feature_id}/asset?type={feature_type}')
-        if res.json()["message"]:
-            raise Exception(res.json()["message"])
-        data = res.json()['data']
-        feature_path = ''
-        if data['path'] is not None:
-            feature_path = data['path']
-        return feature_path
+        for i in range(100):
+            res = self._session.get(
+                url=f'{self.api_address}/{self.app_id}/data/feature/{feature_id}/asset?type={feature_type}', headers={"client-ip": client_ip})
+            if res.json()["message"]:
+                raise Exception(res.json()["message"])
+            data = res.json()['data']
+            if data is '':
+                time.sleep(6)
+                continue
+            if data['path'] is not None:
+                return data['path']
+        raise Exception('转换超时，请联系管理员处理。')
 
     @with_api_exceptions_handler
     def _download_feature_zip(self, feature_id, destination, unzip, feature_type):
