@@ -51,6 +51,9 @@ class FeatureType(Enum):
     COCO = "coco"
     FILE = "zip"
     VOC = "pascal_voc"
+    YOLOV5 = "yolov5"
+    YOLOV3DARKNET = "yolov3darknet"
+    YOLOV3KERAS = "yolov3keras"
 
 @unique
 class DataType(Enum):
