@@ -183,7 +183,6 @@ class ProgressIndicator(object):
 class SilentProgressIndicator(ProgressIndicator):
     def __init__(self, total, filename=None):
         self.filename = filename
-        self.total = total
         if total <= 1024:
             self.total = total
             self.unit = 'Bytes'
@@ -199,61 +198,25 @@ class SilentProgressIndicator(ProgressIndicator):
     def complete(self):
         self.tqdm.update(self.total)
         self.tqdm.close()
-        # return
-        # if self.filename:
-        #     _logger.warning('[%s] 资源文件 任务进度 %.2f KB (100%%)', self.filename, self.total / 1024)
-        # else:
-        #     _logger.warning('所有任务均已完成 %.2f KB (100%%)', self.total / 1024)
 
 
 class LoggingProgressIndicator(ProgressIndicator):
     def __init__(self, total, filename=None, frequency=10):
         self.current = 0
         self.filename = filename
-        self.total = total
+        self.total = total / (1024 * 1024)
         self.last_warning = time.time()
         self.frequency = frequency
-        self.tqdm = tqdm(total=total / (1024 * 1024), desc=f'{self.filename}: size={round(total / (1024 * 1024), 3)}MB',
-                         unit='MB')
-        # _logger.warning('[%s] 资源文件 大小为 %.2fMB 任务耗时较长，请耐心等待。', self.filename, self.total / (1024 * 1024))
+        self.unit = 'MB'
+        self.tqdm = tqdm(total=self.total, desc=f'{self.filename}: size={round(self.total, 3)}{self.unit}',
+                         unit=self.unit)
 
     def progress(self, steps):
-        self.current += steps
-        self.tqdm.update(self.current / (1024 * 1024))
-        # if time.time() - self.last_warning > self.frequency:
-        #     _logger.warning('[%s] 资源文件 任务进度 %.2f MB / %.2f MB (%.2f%%)', self.filename, self.current / (1024 * 1024),
-        #                     self.total / (1024 * 1024), 100 * self.current / self.total)
-        #     self.last_warning = time.time()
+        self.current = steps / (1024 * 1024)
+        self.tqdm.update(self.current)
 
     def complete(self):
-        self.tqdm.update(self.total / (1024 * 1024))
         self.tqdm.close()
-        # _logger.warning('所有任务均已完成 %.2f MB (100%%)', self.total / (1024 * 1024))
-
-
-# class LoggingUploadProgressIndicator(ProgressIndicator):
-#     def __init__(self, total, filename=None, frequency=10):
-#         self.current = 0
-#         self.filename = filename
-#         self.total = total
-#         self.last_warning = time.time()
-#         self.frequency = frequency
-#         _logger.warning('You are sending %dMB of source code to WaveletAI. '
-#                         'It is pretty uncommon - please make sure it\'s what you wanted.',
-#                         self.total / (1024 * 1024))
-#
-#     def progress(self, steps):
-#         self.current += steps
-#         if time.time() - self.last_warning > self.frequency:
-#             _logger.warning('%d MB / %d MB (%d%%) of source code was sent to WaveletAI.',
-#                             self.current / (1024 * 1024),
-#                             self.total / (1024 * 1024),
-#                             100 * self.current / self.total)
-#             self.last_warning = time.time()
-#
-#     def complete(self):
-#         _logger.warning('%d MB (100%%) of source code was sent to WaveletAI.',
-#                         self.total / (1024 * 1024))
 
 
 def split_upload_files(upload_entries, max_package_size=1 * 1024 * 1024, max_files=500):
